@@ -6,9 +6,8 @@ class DeviceMagic():
 
     def __init__(self, args={}):
         self.api_key = args.get('api_key')
-        session = requests.Session()
-        session.auth = DeviceMagicAuth(self.api_key)
-        self.session = session
+        self.session = requests.Session()
+        self.session.auth = DeviceMagicAuth(self.api_key)
         self.form_id = str(args.get('form_id'))
         self.database_id = str(args.get('database_id'))
         self.org_id = str(args.get('org_id'))
@@ -19,34 +18,39 @@ class DeviceMagic():
     @property
     def resource(self):
         from .resource import Resource
-        return Resource(self.session, self.file_path)
+        return Resource(self.connector, self.file_path)
 
     @property
     def database(self):
         from .database import Database
-        return Database(self.session, self.database_id)
+        return Database(self.connector, self.database_id)
 
     @property
     def destination(self):
         from .destination import Destination
-        return Destination(self.session, self.form_id)
+        return Destination(self.connector, self.form_id)
 
     @property
     def device(self):
         from .device import Device
-        return Device(self.session, self.org_id)
+        return Device(self.connector, self.org_id)
 
     @property
     def form(self):
         from .form import Form
-        return Form(self.session, self.org_id)
+        return Form(self.connector, self.org_id)
 
     @property
     def group(self):
         from .group import Group
-        return Group(self.session, self.org_id)
+        return Group(self.connector, self.org_id)
 
     @property
     def dispatch(self):
         from .dispatch import Dispatch
-        return Dispatch(self.session, self.org_id)
+        return Dispatch(self.connector, self.org_id)
+
+    @property
+    def connector(self):
+        from .connector import Connector
+        return Connector(self.session)
